#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_CSC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_CSC_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/csc.hpp>

#endif
